===================
Developer reference
===================

Listing solvers
===============

.. autofunction:: nbkode.get_groups

.. autofunction:: nbkode.get_solvers


Solvers
=======


Fixed step
----------

.. autoclass:: nbkode.ForwardEuler

|

.. autoclass:: nbkode.BackwardEuler

|

.. autoclass:: nbkode.AdamsBashforth1

|

.. autoclass:: nbkode.AdamsBashforth2

|

.. autoclass:: nbkode.AdamsBashforth3

|

.. autoclass:: nbkode.AdamsBashforth4

|

.. autoclass:: nbkode.AdamsBashforth5

|

.. autoclass:: nbkode.AdamsMoulton1

|

.. autoclass:: nbkode.AdamsMoulton2

|

.. autoclass:: nbkode.AdamsMoulton3

|

.. autoclass:: nbkode.AdamsMoulton4

|

.. autoclass:: nbkode.AdamsMoulton5



Variable step
-------------

.. autoclass:: nbkode.DOP853

|

.. autoclass:: nbkode.RungeKutta23

|

.. autoclass:: nbkode.RungeKutta45

